#include <stdio.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/ioctl.h>
#include <fcntl.h>
#include <signal.h>
#include <time.h>
#include "lcd.h"

int
main()
{
    lcd_reset_pwsw();

    while(1){
	chk_pwsw();
	print_time();
	sleep(1);
    }

    return 0;
}

int
print_time()
{
    char line1[64], line2[64];
    time_t ctim;
    struct tm *ctm;

    time( &ctim );
    ctm = localtime( &ctim );

    sprintf( line1, "%4.4d/%2.2d/%2.2d", 
	     ctm->tm_year +1900,
	     ctm->tm_mon +1,
	     ctm->tm_mday );
    sprintf( line2, "%2.2d:%2.2d:%2.2d",
	     ctm->tm_hour,
	     ctm->tm_min,
	     ctm->tm_sec );

    print_lcd( line1, line2 );

    return 0;
}

int
chk_pwsw()
{
    int i;
    char buff[64];

    if( lcd_read_pwsw() == 0 ){
	return 0;
    }

    print_lcd( "shutdwon OK?", "" );
    sleep(5);

    lcd_reset_pwsw();
    for( i=10; i>0; --i ){
	sprintf( buff, "push Power SW %2.2d", i );
	print_lcd( "To shutdown.", buff  );
	if( lcd_read_pwsw() ){
	    do_shutdown();
	}
	--i;
	sleep(1);

       	sprintf( buff, "wait 10 sec   %2.2d", i );
	print_lcd( "To continue",  buff   );
	if( lcd_read_pwsw() ){
	    do_shutdown();
	}
	sleep(1);
    }
}

int
do_shutdown()
{
    print_lcd( "Start shutdown", "process..."   );

    execl( "/sbin/shutdown", "/sbin/shutdown", "-h", "now",  NULL );

    exit(0);
}


int
print_lcd( char *line1, char *line2 )
{
    int fd;
    char buff[128];

    fd = open( "/dev/lcd0", O_RDWR );
    if( fd < 0 ){
	fprintf( stderr, "file open error\n" );
	return -1;
    }

    write( fd, "\f", 1 );

    sprintf( buff, "%-16.16s\n", line1 );
    write( fd, buff, strlen(buff) );
    sprintf( buff, "%-16.16s", line2 );
    write( fd, buff, strlen(buff) );

    close( fd );

    return 0;
}


int
lcd_reset_pwsw()
{
    int fd;
    int dummy;

    while( lcd_read_pwsw() ){
	fd = open( "/dev/lcd0", O_RDWR );
	ioctl( fd, LCD_RESET_PWSW, &dummy );
	close(fd);
    }

    return 0;
}


int
lcd_read_pwsw()
{
    int fd;
    int data;

    fd = open( "/dev/lcd0", O_RDWR );
    ioctl( fd, LCD_READ_PWSW, &data );
    close(fd);

    return data;
}

